emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/heap fcf3edd 18/31: Added autoload cookies.


From: Stefan Monnier
Subject: [elpa] externals/heap fcf3edd 18/31: Added autoload cookies.
Date: Mon, 14 Dec 2020 12:13:36 -0500 (EST)

branch: externals/heap
commit fcf3edd5d63ca4c7dd114d97b269a2f5a9776ac1
Author: Toby S. Cubitt <toby-predictive@dr-qubit.org>
Commit: Toby S. Cubitt <toby-predictive@dr-qubit.org>

    Added autoload cookies.
---
 heap.el | 9 +++++++--
 1 file changed, 7 insertions(+), 2 deletions(-)

diff --git a/heap.el b/heap.el
index 81fef88..7efebb55 100644
--- a/heap.el
+++ b/heap.el
@@ -52,7 +52,7 @@
 ;; based on binary trees might be more suitable, but is not currently
 ;; implemented in this package.)
 ;;
 ;; You create a heap using `heap-create', add elements to it using
 ;; `heap-add', delete and return the root of the heap using
 ;; `heap-delete-root', and modify an element of the heap using
 ;; `heap-modify'. A number of other heap convenience functions are also
@@ -180,7 +180,8 @@
 ;;; ================================================================
 ;;;          The public functions which operate on heaps.
 
-(defun heap-create
+;;;###autoload
+(defun make-heap
   (compare-function &optional initial-size resize-factor)
   "Create an empty heap with comparison function COMPARE-FUNCTION.
 
@@ -201,6 +202,10 @@ defaulting to 2."
   (heap--create compare-function initial-size resize-factor))
 
 
+;;;###autoload
+(defalias 'heap-create 'make-heap)
+
+
 (defun heap-copy (heap)
  "Return a copy of heap HEAP."
  (let ((newheap (heap--create (heap--cmpfun heap) (heap--size heap)
@@ -52,7 +52,7 @@
 ;; implemented in this package.)
 ;;
-;; You create a heap using `heap-create', add elements to it using
+;; You create a heap using `make-heap', add elements to it using
 ;; `heap-add', delete and return the root of the heap using
 ;; `heap-delete-root', and modify an element of the heap using



reply via email to

[Prev in Thread] Current Thread [Next in Thread]